.stacks-embed div.play-icon-container {
    cursor: pointer;
    position: relative;
    float:left;
    width:100%;
}

.stacks-embed div.play-icon {
    position:absolute;
    width: 100%;
    height: 100%;
    background:url(../images/play-icon.png) no-repeat;
    background-position:50% 50%;
    background-size:20%;
}

.stacks-embed div.play-icon:hover {
    background-image:url(../images/play-icon-hover.png);
}
