<!--StacksEmbedList 2-up Grid-->

<div class="stacks-module list-2up stacks-embed stacks-embed-list-2up grid {{ addl_classes }}">
    {% if self.title %}<h2 class="module-title">{{ self.title }}</h2>{% endif %}
    {% for embed in self.embeds %}
    {% if forloop.first or forloop.counter0|divisibleby:'2' %}
    <div class="media-row grid-row">
    {% endif %}
        <div class="grid-block grid-2up
            {% if forloop.first or forloop.counter0|divisibleby:'2' %}first-in-row{% endif %} {% if forloop.counter|divisibleby:'2' %}last-in-row{% endif %}">
            <div class="grid-block-inner">
                {{ embed }}
            </div>
        </div>
    {% if forloop.last or forloop.counter|divisibleby:'2' %}
    </div>
    {% endif %}
    {% endfor %}
</div>
