<!--StacksEmbedList 1-up Grid-->

<div class="stacks-module list-1up stacks-embed stacks-embed-list-1up grid {{ addl_classes }}">
    {% if self.title %}<h2 class="module-title">{{ self.title }}</h2>{% endif %}
    {% for embed in self.embeds %}
    <div class="media-row grid-row">
        <div class="grid-block grid-1up first-in-row">
            <div class="grid-block-inner">
                {{ embed }}
            </div>
        </div>
    </div>
    {% endfor %}
</div>
