<!--StacksEmbed Full Width-->
{% load renditionaware_image_tags %}

<div class="stacks-module stacks-embed full-width grid {{ addl_classes }}">
    {% if self.overline %}
    <h3 class="overline">{{ self.overline }}</h3>
    {% endif %}
    {% if self.title %}<h2 class="module-title">{{ self.title }}</h2>{% endif %}
    <div class="grid-1up">
        <div class="js-embed-placeholder grid wgbh-ga-click" data-wgbh-ga='{{ self.embed.name|slugify }}' data-embed-code='{{ self.embed.embed_code }}'>
            <div class="play-icon-container">
                <div class="play-icon"></div>
                {% image self.embed.poster_image image_rendition as img %}
                <img class="lazy" data-original="{{ img.url }}" alt="{{ self.title }}"/>
            </div>
        </div>
        {% if self.additional_content %}
        <div class="text-container">
            {{ self.additional_content }}
        </div>
        {% endif %}
    </div>
</div>

